@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union, cast
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.apigateway_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -64,7 +76,7 @@ class ApiGatewayServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[ApiGatewayServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -379,7 +391,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -434,7 +446,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, ApiGatewayServiceTransport, None] = None,
+        transport: Optional[Union[str, ApiGatewayServiceTransport]] = None,
         client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -532,11 +544,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def list_gateways(
         self,
-        request: Union[apigateway.ListGatewaysRequest, dict] = None,
+        request: Optional[Union[apigateway.ListGatewaysRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGatewaysPager:
         r"""Lists Gateways in a given project and location.
@@ -647,11 +659,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def get_gateway(
         self,
-        request: Union[apigateway.GetGatewayRequest, dict] = None,
+        request: Optional[Union[apigateway.GetGatewayRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.Gateway:
         r"""Gets details of a single Gateway.
@@ -753,13 +765,13 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def create_gateway(
         self,
-        request: Union[apigateway.CreateGatewayRequest, dict] = None,
+        request: Optional[Union[apigateway.CreateGatewayRequest, dict]] = None,
         *,
-        parent: str = None,
-        gateway: apigateway.Gateway = None,
-        gateway_id: str = None,
+        parent: Optional[str] = None,
+        gateway: Optional[apigateway.Gateway] = None,
+        gateway_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new Gateway in a given project and
@@ -896,12 +908,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def update_gateway(
         self,
-        request: Union[apigateway.UpdateGatewayRequest, dict] = None,
+        request: Optional[Union[apigateway.UpdateGatewayRequest, dict]] = None,
         *,
-        gateway: apigateway.Gateway = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        gateway: Optional[apigateway.Gateway] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates the parameters of a single Gateway.
@@ -1031,11 +1043,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def delete_gateway(
         self,
-        request: Union[apigateway.DeleteGatewayRequest, dict] = None,
+        request: Optional[Union[apigateway.DeleteGatewayRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a single Gateway.
@@ -1155,11 +1167,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def list_apis(
         self,
-        request: Union[apigateway.ListApisRequest, dict] = None,
+        request: Optional[Union[apigateway.ListApisRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListApisPager:
         r"""Lists Apis in a given project and location.
@@ -1270,11 +1282,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def get_api(
         self,
-        request: Union[apigateway.GetApiRequest, dict] = None,
+        request: Optional[Union[apigateway.GetApiRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.Api:
         r"""Gets details of a single Api.
@@ -1372,13 +1384,13 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def create_api(
         self,
-        request: Union[apigateway.CreateApiRequest, dict] = None,
+        request: Optional[Union[apigateway.CreateApiRequest, dict]] = None,
         *,
-        parent: str = None,
-        api: apigateway.Api = None,
-        api_id: str = None,
+        parent: Optional[str] = None,
+        api: Optional[apigateway.Api] = None,
+        api_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new Api in a given project and location.
@@ -1509,12 +1521,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def update_api(
         self,
-        request: Union[apigateway.UpdateApiRequest, dict] = None,
+        request: Optional[Union[apigateway.UpdateApiRequest, dict]] = None,
         *,
-        api: apigateway.Api = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        api: Optional[apigateway.Api] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates the parameters of a single Api.
@@ -1637,11 +1649,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def delete_api(
         self,
-        request: Union[apigateway.DeleteApiRequest, dict] = None,
+        request: Optional[Union[apigateway.DeleteApiRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a single Api.
@@ -1761,11 +1773,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def list_api_configs(
         self,
-        request: Union[apigateway.ListApiConfigsRequest, dict] = None,
+        request: Optional[Union[apigateway.ListApiConfigsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListApiConfigsPager:
         r"""Lists ApiConfigs in a given project and location.
@@ -1876,11 +1888,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def get_api_config(
         self,
-        request: Union[apigateway.GetApiConfigRequest, dict] = None,
+        request: Optional[Union[apigateway.GetApiConfigRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.ApiConfig:
         r"""Gets details of a single ApiConfig.
@@ -1979,13 +1991,13 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def create_api_config(
         self,
-        request: Union[apigateway.CreateApiConfigRequest, dict] = None,
+        request: Optional[Union[apigateway.CreateApiConfigRequest, dict]] = None,
         *,
-        parent: str = None,
-        api_config: apigateway.ApiConfig = None,
-        api_config_id: str = None,
+        parent: Optional[str] = None,
+        api_config: Optional[apigateway.ApiConfig] = None,
+        api_config_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new ApiConfig in a given project and
@@ -2116,12 +2128,12 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def update_api_config(
         self,
-        request: Union[apigateway.UpdateApiConfigRequest, dict] = None,
+        request: Optional[Union[apigateway.UpdateApiConfigRequest, dict]] = None,
         *,
-        api_config: apigateway.ApiConfig = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        api_config: Optional[apigateway.ApiConfig] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates the parameters of a single ApiConfig.
@@ -2245,11 +2257,11 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def delete_api_config(
         self,
-        request: Union[apigateway.DeleteApiConfigRequest, dict] = None,
+        request: Optional[Union[apigateway.DeleteApiConfigRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a single ApiConfig.
@@ -2381,14 +2393,9 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-api-gateway",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ApiGatewayServiceClient",)
